%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% LaTeX document class for UDES-FLSH term papers 
%% Version: 1.1
%% Date: 2021/10/15
%% Author: Yves Bouchard (yves.bouchard@usherbrooke.ca)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


% ==============
% INITIALIZATION
% ==============
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{flshpaper}[2021/10/15 UDES-FLSH term paper document class]

% -------
% OPTIONS
% -------
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions\relax
\LoadClass{article}

% --------
% PACKAGES
% --------
\RequirePackage[utf8]{inputenc}
\RequirePackage[T1]{fontenc}
\RequirePackage[french]{babel}
\RequirePackage{csquotes}
\RequirePackage{graphicx}
\RequirePackage{fancyhdr}
\RequirePackage{setspace}
\RequirePackage[vmargin=1.5cm,hmargin=3cm]{geometry}
\RequirePackage[bottom]{footmisc}
\RequirePackage[bookmarks,
				bookmarksnumbered,
				bookmarksdepth=3,
				bookmarksopen,
				bookmarksopenlevel=3]{hyperref}


% ------------
% CONDITIONALS
% ------------
\newif\if@twoside
\@ifclasswith{article}{twoside} {\@twosidetrue} {\@twosidefalse}


% ===========
% PAGE LAYOUT
% ===========

% Default line spacing
\renewcommand{\baselinestretch}{2} 
% Sectioning with dots (3 levels)
\renewcommand{\thesection}{\arabic{section}.}
\renewcommand{\thesubsection}{\thesection\arabic{subsection}.}
\renewcommand{\thesubsubsection}{\thesubsection\arabic{subsubsection}.}
% Decimal enumerated list (3 levels)
\renewcommand{\labelenumii}{\theenumii}
\renewcommand{\theenumii}{\theenumi.\arabic{enumii}.}
\renewcommand{\labelenumiii}{\theenumiii}
\renewcommand{\theenumiii}{\theenumii\arabic{enumiii}.}
% Quotation
\renewenvironment{quotation}
{\singlespacing\list{}{\rightmargin\leftmargin}%
	\item\relax\small\ignorespaces}
{\unskip\unskip\endlist}


% ==========
% PAGE STYLE
% ==========

\raggedbottom
\pagestyle{fancy}
\fancyhf{}
\fancyfoot[LE]{\thepage}
\fancyfoot[RO]{\thepage}
\footskip20pt
\renewcommand{\headrulewidth}{0pt}
\renewcommand{\footrulewidth}{0pt}

% -----
% INFOS
% -----
\renewcommand{\title}[1]{\def\flshtitle{\textit{#1}}}
\renewcommand{\author}[1]{\def\flshauthor{#1}}
\newcommand{\professor}[1]{\def\flshprofessor{#1}}
\newcommand{\course}[1]{\def\flshcourse{#1}}
\newcommand{\department}[1]{\def\flshdepartment{#1}}
\newcommand{\campus}[1]{\def\flshcampus{#1}}
\renewcommand{\date}[1]{\def\date{#1}}

% --------------
% IDENTIFICATION
% --------------
\newcommand{\makeidentification}{%
	\clearpage
	\thispagestyle{empty}
	\begin{singlespace}
	\hspace{-10pt}
	\begin{tabular*}{0.95\textwidth}{l@{\extracolsep{\fill}}r}
	\flshauthor & remis \`{a} \flshprofessor \\ 
	\date & \flshcourse \\ 
	\hline 
	\end{tabular*}
	\vspace{1cm}
	\end{singlespace}
	}

% ----------
% TITLE PAGE
% ----------
\renewcommand{\maketitle}{%
	\if@twoside\addtocounter{page}{-2}\else\addtocounter{page}{-1}\fi
	\clearpage
	\addcontentsline{toc}{section}{Page titre}
	\thispagestyle{empty}
	\doublespacing
	\begin{center}
	\flshdepartment \\ 
	Facult\'{e} des lettres et sciences humaines \\
	Universit\'{e} de Sherbrooke \\[4cm]
	\flshtitle \\[2cm]
	par \\ \flshauthor \\ \vfill
	Remis \`{a} \\ \flshprofessor \\[2cm]
	Dans le cadre de l'activit\'{e} p\'{e}dagogique \\
	\flshcourse
	\vfill
	\flshcampus \\
	\date\par
	\end{center}
	\clearpage{\thispagestyle{empty}\cleardoublepage}
	}

